@@ -37,6 +37,7 @@ __all__ = (
     "StatusValuesType",
     "TargetTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -351,3 +352,15 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_account_assignment_creation_status",
+    "list_account_assignment_deletion_status",
+    "list_account_assignments",
+    "list_accounts_for_provisioned_permission_set",
+    "list_instances",
+    "list_managed_policies_in_permission_set",
+    "list_permission_set_provisioning_status",
+    "list_permission_sets",
+    "list_permission_sets_provisioned_to_account",
+    "list_tags_for_resource",
+]
